@@ -22,7 +22,7 @@
 from TableFormula import Formula
 from types import *
 import operator
-import copy
+import string, types, copy
 import pickle
 
 class TableModel(object):
@@ -74,7 +74,7 @@ class TableModel(object):
         #add rows and cols if they are given in the constructor
         if newdict == None:
             if rows != None:
-                self.auto_AddRows(rows)
+                self.autoAddRows(rows)
             if columns != None:
                 self.auto_AddColumns(columns)
         self.filteredrecs = None
@@ -108,33 +108,29 @@ class TableModel(object):
         self.reclist = self.data.keys()
         return
 
-    def importDict(self, newdata, namefield=None):
-        """Try to create a table model from some arbitrary dict"""
-        import types
-        if namefield == None:
-            namefield = 'name'
+    def importDict(self, newdata):
+        """Try to create a table model from a dict of the form
+           {{'rec1': {'col1': 3, 'col2': 2}, ..}"""
+
+        #if namefield == None:
+        #    namefield = newdata.keys()[0][0]
         #get cols from sub data keys
         colnames = []
-        colnames.append(namefield)
-
+        #colnames.append(namefield)
         for k in newdata:
             fields = newdata[k].keys()
             for f in fields:
                 if not f in colnames:
                     colnames.append(f)
-
         for c in colnames:
             self.addColumn(c)
-
         #add the data
-        #print colnames
         for k in newdata:
             self.addRow(k)
             for c in colnames:
-                if c == namefield:
-                    self.data[k][namefield] = str(k)
-                else:
-                    self.data[k][c] = str(newdata[k][c])
+                #if c == namefield:
+                #    self.data[k][namefield] = str(k)
+                self.data[k][c] = str(newdata[k][c])
 
         return
 
@@ -144,7 +140,6 @@ class TableModel(object):
 
     def getData(self):
         """Return the current data for saving"""
-        import copy
         data = copy.deepcopy(self.data)
         data['colors'] = self.colors
         data['columnnames'] = self.columnNames
@@ -241,10 +236,9 @@ class TableModel(object):
             return None
         currname = self.getRecName(rowIndex)
         self.reclist[rowIndex] = newname
-        import copy
         temp = copy.deepcopy(self.data[currname])
         self.data[newname] = temp
-        self.data[newname]['Name'] = newname
+        #self.data[newname]['Name'] = newname
         del self.data[currname]
         for key in ['bg', 'fg']:
             if self.colors[key].has_key(currname):
@@ -345,11 +339,10 @@ class TableModel(object):
         self.columnNames=[]
         #self.columnOrder=[]
 
-        print oldcolumnIndex, newcolumnIndex
         #write out a new column names list - tedious
         moved = self.oldnames[oldcolumnIndex]
         del self.oldnames[oldcolumnIndex]
-        print self.oldnames
+        #print self.oldnames
         i=0
         for c in self.oldnames:
             if i==newcolumnIndex:
@@ -363,23 +356,30 @@ class TableModel(object):
             self.columnNames.append(moved)
             #self.columnOrder.append(moved)
 
-        print self.columnNames
-
+        #print self.columnNames
         return
 
-    def addRow(self, name=None, **kwargs):
+    def getNextKey(self):
+        """Return the next numeric key in the dict"""
+        num = len(self.reclist)+1
+        return num
+
+    def addRow(self, key=None, **kwargs):
         """Add a row"""
-        if self.data.has_key(name) or name in self.reclist:
+        if key == '':
+            return
+        if key==None:
+            key = self.getNextKey()
+        if self.data.has_key(key) or key in self.reclist:
             print 'name already present!!'
             return
-        self.data[name]={}
-        if name != None:
-            self.data[name]['Name'] = name
-        else:
-            self.data[name]['Name'] = ''
-        self.reclist.append(name)
-
-        return
+        self.data[key]={}
+        self.reclist = self.data.keys()
+        for k in kwargs:
+            if not k in self.columnNames:
+                self.addColumn(k)
+            self.data[key][k] = str(kwargs[k])
+        return key
 
     def deleteRow(self, rowIndex, update=True):
         """Delete a row"""
@@ -447,35 +447,19 @@ class TableModel(object):
             self.deleteColumn(col)
         return
 
-    def auto_AddRows(self, numrows=None):
+    def autoAddRows(self, numrows=None):
         """Automatically add x number of records"""
-        import string
-        alphabet = string.lowercase[:26]
         rows = self.getRowCount()
-
-        if rows <= 25:
-            i=rows
-            j=0
-        else:
-            i=int(rows%25)
-            j=int(round(rows/25,1))
-        #print i, j
-        for x in range(numrows):
-            if i >= len(alphabet):
-                i=0
-                j=j+1
-            name = alphabet[i]+str(j)
-            if name in self.reclist:
-                pass
-            else:
-                self.addRow(name)
-            i=i+1
-            #print self.reclist
-        return
+        ints = [i for i in self.reclist if isinstance(i, int)]
+        start = max(ints)+1
+        keys = range(start,start+numrows)
+        for k in keys:
+            self.addRow(k)
+        return keys
 
     def auto_AddColumns(self, numcols=None):
         """Automatically add x number of cols"""
-        import string
+
         alphabet = string.lowercase[:26]
         currcols=self.getColumnCount()
         #find where to start
@@ -527,7 +511,7 @@ class TableModel(object):
         """Return the data in a list for this col,
             filterby is a tuple of key, value that allows to filter by rec attribute
         """
-        import types
+
         if columnIndex != None:
             columnName = self.getColumnName(columnIndex)
         coldata = []
@@ -555,6 +539,7 @@ class TableModel(object):
             allowempty: boolean if false means rows with empty vals for any
             required fields are not returned
             returns: lists of column data"""
+
         def evaluate(l):
             for i in l:
                 if i == '' or i == None:
@@ -755,7 +740,7 @@ class TableModel(object):
 
     def merge(self, model, key='name', fields=None):
         """Merge another table model with this one based on a key field,
-           we only add nrecords from the new model where the key is present
+           we only add records from the new model where the key is present
            in both models"""
         if fields == None: fields = model.columnNames
         for rec in self.reclist:
@@ -774,7 +759,7 @@ class TableModel(object):
                         self.data[rec][f] = model.data[rec][f]
         return
 
-    def addRecord(self, name, **kwargs):
+    '''def addRecord(self, name, **kwargs):
         """Add new rec with all fields in kwargs dict"""
         #name = kwargs[kwargs.keys()[0]]
         self.addRow(name)
@@ -784,7 +769,7 @@ class TableModel(object):
             if not k in self.columnNames:
                 self.addColumn(k)
             self.data[name][k] = str(kwargs[k])
-        return
+        return'''
 
     def save(self, filename=None):
         """Save model to file"""
@@ -798,14 +783,14 @@ class TableModel(object):
 
     def load(self, filename):
         """Load model from pickle file"""
-
         fd=open(filename,'r')
-        self.data = pickle.load(fd)
+        data = pickle.load(fd)
+        self.setupModel(data)
         return
 
     def copy(self):
         """Return a copy of this model"""
-        M=TableModel()
+        M = TableModel()
         data = self.getData()
         M.setupModel(data)
         return M
